library(FSA)
library(propagate)
library(minpack.lm)

#Load data
data<-read.csv("Femur Histology Data.csv", header=TRUE)
data
sue<-subset(data, data$Nickname=='Sue')
petey<-subset(data, data$Nickname=='Petey')
jane<-subset(data, data$Nickname=='Jane')
janeC<-subset(data, data$Nickname=='Jane (corrected)')

#Plot
plot(sue$X.LAG.no...including.periosteum, sue$Mass..kg...Campione.et.al...2014...eqn..7.., xlab="LAG number at death (age independent)", ylab="Body mass estimate (kg)",cex.lab=1.25, xlim=c(-10,20), ylim=c(0,2000), col='white')

abline(h=954, col='brown') #Hutchinson value for Jane


##########

#fit logistic growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.janeC <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=900, k=-0.3, p=1.25), data=as.list(janeC))
logistic.janeC
points(x=seq(from=-20, to=50, by=0.1), y=(1265.3519)/(1+exp((1.0416)+(-0.4025)*(seq(from=-20, to=50, by=0.1)))), type="l", col="BLUE", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.janeC<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=900), data=as.list(janeC))
gompertz.janeC
points(x=seq(from=-20, to=50, by=0.1), y=(1439.0916)*2.71828^(-2.71828^(-(0.2436)*(seq(from=-20, to=50, by=0.1)-(1.7523)))), type="l", col="BLUE", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit Logarithmic growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
model.janeC <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.janeC,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='BLUE', lty=3)

#fit VB growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define von bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(janeC),start=list(Linf=1000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(2097.14183)*(1-exp(-(0.08525)*((seq(from=-20, to=50, by=0.1))-(-1.68552)))), type="l", col="BLUE", lwd=2, lty=4) #Insert the parameters found in the model manually


##########

#fit logistic growth model to whole Jane data
x<-as.numeric(jane$X.LAG.no...including.periosteum)
y<-as.numeric(jane$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.jane <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=900, k=-0.3, p=1.25), data=as.list(jane))
logistic.jane
points(x=seq(from=-20, to=50, by=0.1), y=(1059.8367)/(1+exp((0.6913)+(-0.4063)*(seq(from=-20, to=50, by=0.1)))), type="l", col="lightblue", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole Jane data
x<-as.numeric(jane$X.LAG.no...including.periosteum)
y<-as.numeric(jane$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.jane<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=900), data=as.list(jane))
gompertz.jane
points(x=seq(from=-20, to=50, by=0.1), y=(1090.7370)*2.71828^(-2.71828^(-(0.3068)*(seq(from=-20, to=50, by=0.1)-(0.6393)))), type="l", col="lightblue", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit Logarithmic growth model to whole Jane data
x<-as.numeric(jane$X.LAG.no...including.periosteum)
y<-as.numeric(jane$Mass..kg...Campione.et.al...2014...eqn..7..)
model.jane <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.jane,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='lightblue', lty=3)

#fit VB growth model to whole Jane data
x<-as.numeric(jane$X.LAG.no...including.periosteum)
y<-as.numeric(jane$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define von bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(jane),start=list(Linf=1000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(1149.7862)*(1-exp(-(0.2059)*((seq(from=-20, to=50, by=0.1))-(-1.3183)))), type="l", col="lightblue", lwd=2, lty=4) #Insert the parameters found in the model manually


##########

#fit logistic growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.petey <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=900, k=-0.3, p=1.25), data=as.list(petey))
logistic.petey
points(x=seq(from=-20, to=50, by=0.1), y=(791.6758)/(1+exp((1.7332)+(-0.5991)*(seq(from=-20, to=50, by=0.1)))), type="l", col="GREEN", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.petey<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=900), data=as.list(petey))
gompertz.petey
points(x=seq(from=-20, to=50, by=0.1), y=(862.4254)*2.71828^(-2.71828^(-(0.3729)*(seq(from=-20, to=50, by=0.1)-(2.1634)))), type="l", col="GREEN", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit Logarithmic growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
model.petey <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.petey,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='GREEN', lty=3)

#fit VB growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define von bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(petey),start=list(Linf=1000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(1124.3929)*(1-exp(-(0.1471)*((seq(from=-20, to=50, by=0.1))-(-0.1819)))), type="l", col="GREEN", lwd=2, lty=4) #Insert the parameters found in the model manually




##############################
points(janeC$X.LAG.no...including.periosteum, janeC$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=15)
points(jane$X.LAG.no...including.periosteum, jane$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=0)
points(petey$X.LAG.no...including.periosteum, petey$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=17)

